==> rife-ncnn-vulkan-python-1.1.2.post2.tar.gz: rife-ncnn-vulkan-python-1.1.2.post2/rife_ncnn_vulkan_python/rife-ncnn-vulkan/src/ncnn/src/layer/vulkan/deconvolution_vulkan.h <==
// Tencent is pleased to support the open source community by making ncnn available.
//
// Copyright (C) 2019 THL A29 Limited, a Tencent company. All rights reserved.
//
// Licensed under the BSD 3-Clause License (the "License"); you may not use this file except
// in compliance with the License. You may obtain a copy of the License at
//
// https://opensource.org/licenses/BSD-3-Clause
//
// Unless required by applicable law or agreed to in writing, software distributed
// under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
// CONDITIONS OF ANY KIND, either express or implied. See the License for the
// specific language governing permissions and limitations under the License.

#ifndef LAYER_DECONVOLUTION_VULKAN_H
#define LAYER_DECONVOLUTION_VULKAN_H

#include "deconvolution.h"

namespace ncnn {

class Deconvolution_vulkan : virtual public Deconvolution
{
public:
    Deconvolution_vulkan();

    virtual int create_pipeline(const Option& opt);
    virtual int destroy_pipeline(const Option& opt);

    virtual int upload_model(VkTransfer& cmd, const Option& opt);

    using Deconvolution::forward;
    virtual int forward(const VkMat& bottom_blob, VkMat& top_blob, VkCompute& cmd, const Option& opt) const;
    virtual int forward(const VkImageMat& bottom_blob, VkImageMat& top_blob, VkCompute& cmd, const Option& opt) const;

public:
    VkMat weight_data_gpu;
    VkMat bias_data_gpu;

    VkImageMat weight_data_gpu_image;
    VkImageMat bias_data_gpu_image;

    ncnn::Layer* crop;
    ncnn::Layer* output_crop;

    Pipeline* pipeline_deconvolution;
    Pipeline* pipeline_deconvolution_pack4;
    Pipeline* pipeline_deconvolution_pack1to4;
    Pipeline* pipeline_deconvolution_pack4to1;
    Pipeline* pipeline_deconvolution_pack8;
    Pipeline* pipeline_deconvolution_pack1to8;
    Pipeline* pipeline_deconvolution_pack4to8;
    Pipeline* pipeline_deconvolution_pack8to1;
    Pipeline* pipeline_deconvolution_pack8to4;
};

} // namespace ncnn

#endif // LAYER_DECONVOLUTION_VULKAN_H

==> rife-ncnn-vulkan-python-1.2.1.tar.gz: rife-ncnn-vulkan-python-1.2.1/rife_ncnn_vulkan_python/rife-ncnn-vulkan/src/ncnn/src/layer/vulkan/deconvolution_vulkan.h <==
// Tencent is pleased to support the open source community by making ncnn available.
//
// Copyright (C) 2019 THL A29 Limited, a Tencent company. All rights reserved.
//
// Licensed under the BSD 3-Clause License (the "License"); you may not use this file except
// in compliance with the License. You may obtain a copy of the License at
//
// https://opensource.org/licenses/BSD-3-Clause
//
// Unless required by applicable law or agreed to in writing, software distributed
// under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
// CONDITIONS OF ANY KIND, either express or implied. See the License for the
// specific language governing permissions and limitations under the License.

#ifndef LAYER_DECONVOLUTION_VULKAN_H
#define LAYER_DECONVOLUTION_VULKAN_H

#include "deconvolution.h"

namespace ncnn {

class Deconvolution_vulkan : virtual public Deconvolution
{
public:
    Deconvolution_vulkan();

    virtual int create_pipeline(const Option& opt);
    virtual int destroy_pipeline(const Option& opt);

    virtual int upload_model(VkTransfer& cmd, const Option& opt);

    using Deconvolution::forward;
    virtual int forward(const VkMat& bottom_blob, VkMat& top_blob, VkCompute& cmd, const Option& opt) const;
    virtual int forward(const VkImageMat& bottom_blob, VkImageMat& top_blob, VkCompute& cmd, const Option& opt) const;

public:
    Mat weight_data_packed;
    Mat bias_data_packed;

    VkMat weight_data_gpu;
    VkMat bias_data_gpu;

    VkImageMat weight_data_gpu_image;
    VkImageMat bias_data_gpu_image;

    ncnn::Layer* crop;
    ncnn::Layer* output_crop;

    Pipeline* pipeline_deconvolution;

    Pipeline* pipeline_deconvolution_gemm;
    Pipeline* pipeline_deconvolution_col2im;
};

} // namespace ncnn

#endif // LAYER_DECONVOLUTION_VULKAN_H
